@@ -4,11 +4,13 @@ use strict;
 use warnings;
 
 BEGIN {
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 require XSLoader;
 XSLoader::load('Math::Int64', $VERSION);
 }
 
+use warnings::register;
+
 use constant MAX_INT64  => string_to_int64 ( '0x7fff_ffff_ffff_ffff');
 use constant MIN_INT64  => string_to_int64 ('-0x8000_0000_0000_0000');
 use constant MAX_UINT64 => string_to_uint64( '0xffff_ffff_ffff_ffff');
@@ -64,6 +66,15 @@ sub import {
     Math::Int64->export_to_level(1, $pkg, @subs);
 }
 
+sub _check_pragma_compatibility {
+    if ($^H{'Math::Int64::native_if_available'} and
+        $^H{'Math::Int64::die_on_overflow'} and
+        warnings::enabled()) {
+        warnings::warn("Math::Int64::die_on_overflow pragma is useless when Math::Int64::native_if_available is also active");
+    }
+    1;
+}
+
 use overload ( '+' => \&_add,
                '+=' => \&_add,
                '-' => \&_sub,
